==> mbdyn-1.3.9.tar.gz: mbdyn-1.3.9/mbdyn/base/converged.cc <==
/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/converged.cc,v 1.2 2009/01/04 18:05:02 masarati Exp $ */
/* 
 * MBDyn (C) is a multibody analysis code. 
 * http://www.mbdyn.org
 *
 * Copyright (C) 1996-2009
 *
 * Pierangelo Masarati	<masarati@aero.polimi.it>
 * Paolo Mantegazza	<mantegazza@aero.polimi.it>
 *
 * Dipartimento di Ingegneria Aerospaziale - Politecnico di Milano
 * via La Masa, 34 - 20156 Milano, Italy
 * http://www.aero.polimi.it
 *
 * Changing this copyright notice is forbidden.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation (version 2 of the License).
 * 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef HAVE_CONFIG_H
#include <mbconfig.h>           /* This goes first in every *.c,*.cc file */
#endif /* HAVE_CONFIG_H */

#include "converged.h"
#include "dataman.h"

Converged::Converged(DataManager *pDM)
: pDM(pDM), idx(unsigned(-1))
{
	if (pDM) {
		Register();
	}
}

void
Converged::Register(void)
{
	ASSERT(pDM != NULL);

	idx = pDM->ConvergedRegister();
	if (idx == unsigned(-1)) {
		throw ErrGeneric(MBDYN_EXCEPT_ARGS);
	}
}

Converged::~Converged(void)
{
	NO_OP;
}

void
Converged::Set(bool b)
{
	ASSERT(idx != unsigned(-1));
	pDM->ConvergedSet(idx, b);
}

==> mbdyn-1.4.0.tar.gz: mbdyn-1.4.0/mbdyn/base/converged.cc <==
/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/converged.cc,v 1.7 2011/01/25 20:02:01 masarati Exp $ */
/* 
 * MBDyn (C) is a multibody analysis code. 
 * http://www.mbdyn.org
 *
 * Copyright (C) 1996-2011
 *
 * Pierangelo Masarati	<masarati@aero.polimi.it>
 * Paolo Mantegazza	<mantegazza@aero.polimi.it>
 *
 * Dipartimento di Ingegneria Aerospaziale - Politecnico di Milano
 * via La Masa, 34 - 20156 Milano, Italy
 * http://www.aero.polimi.it
 *
 * Changing this copyright notice is forbidden.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation (version 2 of the License).
 * 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "mbconfig.h"           /* This goes first in every *.c,*.cc file */

#include "converged.h"
#include "dataman.h"

Converged::Converged(DataManager *pDM)
: pDM(pDM), idx(unsigned(-1))
{
	if (pDM) {
		Register();
	}
}

void
Converged::Register(void)
{
	ASSERT(pDM != NULL);

	idx = pDM->ConvergedRegister();
	if (idx == unsigned(-1)) {
		throw ErrGeneric(MBDYN_EXCEPT_ARGS);
	}
}

Converged::~Converged(void)
{
	NO_OP;
}

void
Converged::Set(Converged::State s)
{
	if (idx != unsigned(-1)) {
		pDM->ConvergedSet(idx, s);
	}
}
